@@ -215,17 +215,17 @@ class TestDXBuildApp(unittest.TestCase):
                     raise Exception('A stderr_regexp was supplied but the CalledProcessError did not return the contents of stderr')
                 print "stderr:"
                 print e.stderr
-                self.assertTrue(re.search(stderr_regexp, e.stderr), "Expected stdout to match '%s' but it didn't" % (stderr_regexp,))
+                self.assertTrue(re.search(stderr_regexp, e.stderr), "Expected stderr to match '%s' but it didn't" % (stderr_regexp,))
             return
         self.assertFalse(True, "Expected command to fail with CalledProcessError but it succeeded")
 
-    def write_app_directory(self, app_name, dxapp_str, code_filename=None):
+    def write_app_directory(self, app_name, dxapp_str, code_filename=None, code_content="\n"):
         os.mkdir(os.path.join(self.temp_file_path, app_name))
         with open(os.path.join(self.temp_file_path, app_name, 'dxapp.json'), 'w') as manifest:
             manifest.write(dxapp_str)
         if code_filename:
             with open(os.path.join(self.temp_file_path, app_name, code_filename), 'w') as code_file:
-                code_file.write('\n')
+                code_file.write(code_content)
         return os.path.join(self.temp_file_path, app_name)
 
     def test_help_without_security_context(self):
@@ -384,5 +384,26 @@ class TestDXBuildApp(unittest.TestCase):
         with self.assertSubprocessFailure(stderr_regexp="make in target directory failed with exit code"):
             run("dx-build-applet --no-parallel-build " + app_dir)
 
+    def test_dxapp_checks(self):
+        app_dir = self.write_app_directory("dxapp_checks", "{\"invalid_json\":}", code_filename="code.py")
+        with self.assertSubprocessFailure(stderr_regexp="dxapp\\.json"):
+            run("dx-build-applet " + app_dir)
+
+    def test_syntax_checks(self):
+        app_spec = {
+            "name": "syntax_checks",
+            "dxapi": "1.0.0",
+            "runSpec": {"file": "code.py", "interpreter": "python2.7"},
+            "inputSpec": [],
+            "outputSpec": [],
+            "version": "1.0.0"
+            }
+        app_dir = self.write_app_directory("syntax_checks",
+                                           json.dumps(app_spec),
+                                           code_filename="code.py",
+                                           code_content="def improper():\nprint 'oops'")
+        with self.assertSubprocessFailure(stderr_regexp="Entry point file \\S+ has syntax errors"):
+            run("dx-build-applet " + app_dir)
+
 if __name__ == '__main__':
     unittest.main()
